﻿using System;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Windows.Forms;
using Telerik.WinControls.UI;

namespace RadGridViewExample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.radGridView1.Columns.Add("Image");
            this.radGridView1.Columns[0].Width = 400;

            this.radGridView1.Rows.AddNew();

            this.radGridView1.EditorRequired += new EditorRequiredEventHandler(radGridView1_EditorRequired);
            this.radGridView1.CreateCell += new GridViewCreateCellEventHandler(radGridView1_CreateCell);
        }

        void radGridView1_CreateCell(object sender, GridViewCreateCellEventArgs e)
        {
            if (e.CellType == typeof(GridDataCellElement))
            {
                e.CellElement = new MyDataCellElement(e.Column, e.Row);
            }
        }

        void radGridView1_EditorRequired(object sender, EditorRequiredEventArgs e)
        {
            RadDropDownListEditor editor = new RadDropDownListEditor();
            RadDropDownListEditorElement element = editor.EditorElement as RadDropDownListEditorElement;
            element.VisualItemFormatting += new VisualListItemFormattingEventHandler(element_VisualItemFormatting);

            element.AutoSizeItems = true;
            element.DropDownMinSize = new Size(0, 220);

            for (int i = 1; i < 10; i++)
            {
                Image img = Image.FromFile(@"..\..\Resources\brush" + i + ".png");
                RadListDataItem item = new RadListDataItem();
                item.Image = img;
                item.TextImageRelation = TextImageRelation.ImageBeforeText;

                using (MemoryStream ms = new MemoryStream())
                {
                    if (img is Bitmap)
                    {
                        img.Save(ms, ImageFormat.Bmp);
                    }
                    else
                    {
                        img.Save(ms, img.RawFormat);
                    }

                    byte[] imageBytes = ms.ToArray();
                    item.Text = Convert.ToBase64String(imageBytes);
                }

                element.Items.Add(item);
            }

            e.Editor = editor;
        }

        void element_VisualItemFormatting(object sender, VisualItemFormattingEventArgs args)
        {
            args.VisualItem.DrawText = false;
        }
    }

    public class MyDataCellElement : GridDataCellElement
    {
        public MyDataCellElement(GridViewColumn column, GridRowElement row)
            : base(column, row)
        {
            this.DrawText = false;
        }

        public override void SetContent()
        {
            base.SetContent();
            object value = this.RowInfo.Cells[this.ColumnIndex].Value;

            if (value == null)
            {
                return;
            }

            byte[] imageBytes = Convert.FromBase64String(value.ToString());
            using (MemoryStream ms = new MemoryStream(imageBytes, 0, imageBytes.Length))
            {
                ms.Write(imageBytes, 0, imageBytes.Length);
                this.Image = Image.FromStream(ms, true);
            }
        }

        protected override Type ThemeEffectiveType
        {
            get
            {
                return typeof(GridDataCellElement);
            }
        }
    }
}